==> nextcloud-26.0.11p1.tgz: nextcloud/apps/theming/l10n/lt_LT.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Nurodytas pavadinimas yra per ilgas",
    "The given web address is too long" : "Nurodytas adresas yra per ilgas",
    "The given web address is not a valid URL" : "Nurodytas saityno adresas nėra teisingas URL",
    "The given legal notice address is too long" : "Nurodytas teisinio pranešimo adresas yra per ilgas",
    "The given legal notice address is not a valid URL" : "Nurodytas teisinio pranešimo adresas nėra teisingas URL",
    "The given privacy policy address is too long" : "Nurodytas privatumo politikos adresas yra per ilgas",
    "The given privacy policy address is not a valid URL" : "Nurodytas privatumo politikos adresas nėra teisingas URL",
    "The given slogan is too long" : "Nurodytas šūkis yra per ilgas",
    "The given color is invalid" : "Nurodyta spalva yra neteisinga",
    "Saved" : "Įrašyta",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeliamas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded" : "Neįkeltas joks failas",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Jūs jau naudojate tinkintą apipavidalinimą. Apipavidalinimo programėlės nustatymai gali būti perrašyti to apipavidalinimo.",
    "Theming" : "Apipavidalinimas",
    "Appearance and accessibility" : "Išvaizda ir prieinamumas",
    "Dark theme with high contrast mode" : "Tamsus apipavidalinimas su didelio kontrasto veiksena",
    "Enable dark high contrast mode" : "Įjungti tamsią didelio kontrasto veikseną",
    "Similar to the high contrast mode, but with dark colours." : "Panaši į didelio kontrasto veikseną, tik su tamsiomis spalvomis.",
    "Dark theme" : "Tamsus apipavidalinimas",
    "Enable dark theme" : "Įjungti tamsų apipavidalinimą",
    "System default theme" : "Sistemos numatytasis apipavidalinimas",
    "Enable the system default" : "Įjungti sistemos numatytąjį",
    "Using the default system appearance." : "Naudojama numatytoji sistemos išvaizda.",
    "Dyslexia font" : "Disleksijos šriftas",
    "Enable dyslexia font" : "Įjungti disleksijos šriftą",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas.",
    "High contrast mode" : "Didelio kontrasto veiksena",
    "Enable high contrast mode" : "Įjungti didelio kontrasto veikseną",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto veiksena, skirta palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Light theme" : "Šviesus apipavidalinimas",
    "Enable the default light theme" : "Įjungti numatytąjį šviesų apipavidalinimą",
    "The default light appearance." : "Numatytasis šviesus apipavidalinimas.",
    "Legal notice" : "Teisinis pranešimas",
    "Privacy policy" : "Privatumo politika",
    "Adjust the Nextcloud theme" : "Derinti Nextcloud apipavidalinimą",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Apipavidalinimai leidžia lengvai tinkinti jūsų egzemplioriaus ir palaikomų klientų išvaizdą bei turinį. Tai bus matoma visiems naudotojams.",
    "Advanced options" : "Išplėstinės parinktys",
    "Name" : "Pavadinimas",
    "Web link" : "Internetinė nuoroda",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "Slogan" : "Šūkis",
    "Color" : "Spalva",
    "Logo" : "Logotipas",
    "Upload new logo" : "Įkelti naują logotipą",
    "Legal notice link" : "Teisinio pranešimo nuoroda",
    "Privacy policy link" : "Privatumo politikos nuoroda",
    "Header logo" : "Antraštės logotipas",
    "Upload new header logo" : "Įkelti naują antraštės logotipą",
    "Favicon" : "Svetainės piktograma",
    "Upload new favicon" : "Įkelti naują svetainės piktogramą",
    "User settings" : "Naudotojo nustatymai",
    "Background" : "Fonas",
    "Customization has been disabled by your administrator" : "Administratorius yra išjungęs tinkinimus",
    "Set a custom background" : "Nustatyti tinkintą foną",
    "Keyboard shortcuts" : "Spartieji klavišai",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Mums universalioji prieiga yra labai svarbi. Mes sekame saityno standartus ir stengiamės, kad būtų galima viskuobe pelės ir pagalbinės programinės įrangos, tokios kaip ekrano skaitytuvė. Stengiamės atitikti {guidelines}Saityno turinio prieinamumo gairėms{linkend} 2.1 pagal AA lygmenį, o su didelio kontrasto apipavidalinimu netgi pagal AAA lygmenį.",
    "Move up" : "Pakelti",
    "Move down" : "Nuleisti",
    "Custom background" : "Tinkintas fonas",
    "Default background" : "Numatytasis fonas",
    "Change color" : "Keisti spalvą",
    "Reset to default" : "Atstatyti į numatytąjį",
    "Upload" : "Įkelti",
    "Remove background image" : "Šalinti foninį paveikslą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-27.1.2.tgz: nextcloud/apps/theming/l10n/lt_LT.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Nurodytas pavadinimas yra per ilgas",
    "The given web address is too long" : "Nurodytas adresas yra per ilgas",
    "The given web address is not a valid URL" : "Nurodytas saityno adresas nėra teisingas URL",
    "The given legal notice address is too long" : "Nurodytas teisinio pranešimo adresas yra per ilgas",
    "The given legal notice address is not a valid URL" : "Nurodytas teisinio pranešimo adresas nėra teisingas URL",
    "The given privacy policy address is too long" : "Nurodytas privatumo politikos adresas yra per ilgas",
    "The given privacy policy address is not a valid URL" : "Nurodytas privatumo politikos adresas nėra teisingas URL",
    "The given slogan is too long" : "Nurodytas šūkis yra per ilgas",
    "The given color is invalid" : "Nurodyta spalva yra neteisinga",
    "Saved" : "Įrašyta",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeliamas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded" : "Neįkeltas joks failas",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Jūs jau naudojate tinkintą apipavidalinimą. Apipavidalinimo programėlės nustatymai gali būti perrašyti to apipavidalinimo.",
    "Theming" : "Apipavidalinimas",
    "Appearance and accessibility" : "Išvaizda ir prieinamumas",
    "Dark theme with high contrast mode" : "Tamsus apipavidalinimas su didelio kontrasto veiksena",
    "Enable dark high contrast mode" : "Įjungti tamsią didelio kontrasto veikseną",
    "Similar to the high contrast mode, but with dark colours." : "Panaši į didelio kontrasto veikseną, tik su tamsiomis spalvomis.",
    "Dark theme" : "Tamsus apipavidalinimas",
    "Enable dark theme" : "Įjungti tamsų apipavidalinimą",
    "System default theme" : "Sistemos numatytasis apipavidalinimas",
    "Enable the system default" : "Įjungti sistemos numatytąjį",
    "Using the default system appearance." : "Naudojama numatytoji sistemos išvaizda.",
    "Dyslexia font" : "Disleksijos šriftas",
    "Enable dyslexia font" : "Įjungti disleksijos šriftą",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas.",
    "High contrast mode" : "Didelio kontrasto veiksena",
    "Enable high contrast mode" : "Įjungti didelio kontrasto veikseną",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto veiksena, skirta palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Light theme" : "Šviesus apipavidalinimas",
    "Enable the default light theme" : "Įjungti numatytąjį šviesų apipavidalinimą",
    "The default light appearance." : "Numatytasis šviesus apipavidalinimas.",
    "Legal notice" : "Teisinis pranešimas",
    "Privacy policy" : "Privatumo politika",
    "Adjust the Nextcloud theme" : "Derinti Nextcloud apipavidalinimą",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Apipavidalinimai leidžia lengvai tinkinti jūsų egzemplioriaus ir palaikomų klientų išvaizdą bei turinį. Tai bus matoma visiems naudotojams.",
    "Advanced options" : "Išplėstinės parinktys",
    "Name" : "Pavadinimas",
    "Web link" : "Internetinė nuoroda",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "Slogan" : "Šūkis",
    "Color" : "Spalva",
    "Logo" : "Logotipas",
    "Upload new logo" : "Įkelti naują logotipą",
    "Legal notice link" : "Teisinio pranešimo nuoroda",
    "Privacy policy link" : "Privatumo politikos nuoroda",
    "Header logo" : "Antraštės logotipas",
    "Upload new header logo" : "Įkelti naują antraštės logotipą",
    "Favicon" : "Svetainės piktograma",
    "Upload new favicon" : "Įkelti naują svetainės piktogramą",
    "User settings" : "Naudotojo nustatymai",
    "Background" : "Fonas",
    "Customization has been disabled by your administrator" : "Administratorius yra išjungęs tinkinimus",
    "Set a custom background" : "Nustatyti tinkintą foną",
    "Keyboard shortcuts" : "Spartieji klavišai",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Mums universalioji prieiga yra labai svarbi. Mes sekame saityno standartus ir stengiamės, kad būtų galima viskuobe pelės ir pagalbinės programinės įrangos, tokios kaip ekrano skaitytuvė. Stengiamės atitikti {guidelines}Saityno turinio prieinamumo gairėms{linkend} 2.1 pagal AA lygmenį, o su didelio kontrasto apipavidalinimu netgi pagal AAA lygmenį.",
    "Custom background" : "Tinkintas fonas",
    "Default background" : "Numatytasis fonas",
    "Change color" : "Keisti spalvą",
    "Reset to default" : "Atstatyti į numatytąjį",
    "Upload" : "Įkelti",
    "Remove background image" : "Šalinti foninį paveikslą",
    "Loading preview…" : "Įkeliama peržiūra…",
    "Admin" : "Administravimas",
    "Name cannot be empty" : "Pavadinimas negali būti tuščias",
    "Pick from Files" : "Pasirinkti iš Failų",
    "Default image" : "Numatytasis paveikslas",
    "Custom color" : "Tinkinta spalva",
    "Plain background" : "Vientisas fonas",
    "Insert from {productName}" : "Įterpti iš {productName}",
    "Open documentation" : "Atverti dokumentaciją",
    "https://…" : "https://…",
    "Upload new login background" : "Įkelti naują prisijungimo foną",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Norėdami automatiškai generuoti svetainės piktogramą remiantis įkeltu logotipu ir spalva, įdiekite Imagemagick PHP plėtinį su SVG paveikslų palaikymu."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
